from conans import ConanFile, CMake, tools
import os


class LibOggConan(ConanFile):
    name = "libogg"
    version = "1.3.4"
    license = "BSD-2-Clause"
    author = "Shawn Morford <DarkMorford@Gmail.com>"
    url = "https://code.darkmorford.net/conan-pkg/libogg"
    description = ("Ogg is a multimedia container format, and the native file and stream format for the "
                   "Xiph.org multimedia codecs. As with all Xiph.org technology it is an open format "
                   "free for anyone to use.")
    homepage = "https://www.xiph.org/ogg/"
    topics = ("xiph.org", "media", "container")
    exports_sources = ["CMakeLists.txt"]
    settings = "os", "compiler", "build_type", "arch"
    options = {"shared": [True, False]}
    default_options = {"shared": False}
    generators = "cmake"

    @property
    def subfolder(self):
        return os.path.join(self.source_folder, f"libogg-{self.version}")

    def source(self):
        tools.get(**self.conan_data["sources"][self.version])

    def configure(self):
        del self.settings.compiler.cppstd
        del self.settings.compiler.libcxx

    def _configure_cmake(self):
        cmake = CMake(self)
        cmake.definitions["CONAN_SOURCE_LOCATION"] = self.subfolder
        cmake.configure()
        return cmake

    def build(self):
        cmake = self._configure_cmake()
        cmake.build()

    def package(self):
        self.copy("*.h", dst="include", src="hello")
        self.copy("*hello.lib", dst="lib", keep_path=False)
        self.copy("*.dll", dst="bin", keep_path=False)
        self.copy("*.so", dst="lib", keep_path=False)
        self.copy("*.dylib", dst="lib", keep_path=False)
        self.copy("*.a", dst="lib", keep_path=False)

    def package_info(self):
        self.cpp_info.libs = ["hello"]
